Unicode consortium mapping tables
---------------------------------

- `iso-8859/`: https://www.unicode.org/Public/MAPPINGS/ISO8859
- `microsoft/`: https://www.unicode.org/Public/MAPPINGS/VENDORS/MICSFT/
- `apple/`: https://www.unicode.org/Public/MAPPINGS/VENDORS/APPLE/
- `misc/`: https://www.unicode.org/Public/MAPPINGS/VENDORS/MISC/
- `adobe/`: https://www.unicode.org/Public/MAPPINGS/VENDORS/ADOBE/

http://www.unicode.org/terms_of_use.html
